@@ -34,7 +34,7 @@ BRANCHES = [
 
 def check_git_config(args, parser):
     for branch in BRANCHES:
-        branch_dir = join(locations()['trees'], branch)
+        branch_dir = join(locations()['tree'], branch)
         cur_dir = os.getcwd()
         if os.path.isdir(branch_dir):
             try:
@@ -185,6 +185,8 @@ def check(args, parser):
             print ('Directory {0} does not exist, run checkout.'
                    .format(branch_dir))
 
+def bash(args, parser):
+
 
 def bind(args, parser):
     if args.interfaces:
@@ -253,6 +255,23 @@ def bind(args, parser):
 
 # Helper functions:
 
+def get_project():
+
+    def walk(cur):
+        if 'Dockerfile' in os.listdir(cur):
+            return os.path.basename(cur)
+        new = os.path.dirname(cur)
+        if new == cur:
+            raise ValueError('Dockerfile not find in current parent directories.')
+        return walk(new)
+
+    project = walk(os.getcwd())
+    if project not in BRANCHES:
+        raise ValueError('Project {0} not a valid branch.'.format(project))
+
+    return project
+
+
 def get_config_value(section, key, default=None):
     config = configparser.ConfigParser()
     config.read(CONFIG_PATH)
@@ -385,7 +404,7 @@ def get_interface_data(interface=None):
 
 
 def create_parser():
-    parser = argparse.ArgumentParser(description='Wharfie')
+    parser = argparse.ArgumentParser()
 
     subparsers = parser.add_subparsers(
         help='See each command for additional help',
@@ -405,6 +424,11 @@ def create_parser():
     )
     parser_check.set_defaults(func=check)
 
+    parser_bash = subparsers.add_parser(
+        'bash', help='Bash prompt for a container for this image'
+    )
+    parser_check.set_defaults(func=check)
+
     parser_up = subparsers.add_parser(
         'up', help='Recreates fig.yml and starts the '
                    'containers in the background, a wrapper around `fig up`'
@@ -419,6 +443,7 @@ def create_parser():
         metavar="IMAGE_NAME",
     )
     parser_shell.set_defaults(func=shell)
+
     parser_shell = subparsers.add_parser(
         'chkgitconfig', help='Print out the git config for mkt branches'
     )
